<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 	        xmlns:axsl="http://www.w3.org/1999/XSL/TransformAlias"
	        xmlns:sch="http://www.ascc.net/xml/schematron"
	        xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                version="1.0">
<!--
     This specializes iso-schematron-skeleton.xsl to analyze all assertions
     and abort with a message of all violations.

 $Id: Message-Schematron-terminator.xsl,v 1.3 2007/07/28 20:10:46 G. Ken Holman Exp $

     Implemented as part of the OASIS Schematron-based Value Validation Using
     Genericode (check the latest version of the following document in the
     OASIS repository): 

     http://www.oasis-open.org/committees/document.php?document_id=24810

Copyright (C) OASIS Open (2006). All Rights Reserved.

This document and translations of it may be copied and furnished to others, and
derivative works that comment on or otherwise explain it or assist in its
implementation may be prepared, copied, published and distributed, in whole or
in part, without restriction of any kind, provided that the above copyright
notice and this paragraph are included on all such copies and derivative works.
However, this document itself may not be modified in any way, such as by
removing the copyright notice or references to OASIS, except as needed for the
purpose of developing OASIS specifications, in which case the procedures for
copyrights defined in the OASIS Intellectual Property Rights document must be
followed, or as required to translate it into languages other than English.

The limited permissions granted above are perpetual and will not be revoked by
OASIS or its successors or assigns.

This document and the information contained herein is provided on an "AS IS"
basis and OASIS DISCLAIMS ALL WARRANTIES, EXPRESS OR IMPLIED, INCLUDING BUT NOT
LIMITED TO ANY WARRANTY THAT THE USE OF THE INFORMATION HEREIN WILL NOT
INFRINGE ANY RIGHTS OR ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR
A PARTICULAR PURPOSE.
-->

<!--specialize the published Schematron reference implementation-->
<xsl:import href="iso_schematron_skeleton.xsl"/>

<!--augment with methodology-specific process additions-->
<xsl:template match="node()" mode="stylesheetbody">
  <xsl:comment>Importing stylesheet additions</xsl:comment>
  <axsl:output method="text"/>

  <!--create the reference portion of the stylesheet-->
  <xsl:apply-imports/>
</xsl:template>

<!--this overrides the skeleton handling the root node-->
<xsl:template name="process-root">
  <xsl:param name="contents"/>
  <xsl:comment>Root node processing collects all assertions</xsl:comment>
  <!--first determine the text result of the imported stylesheet-->
  <axsl:variable name="result">
    <xsl:copy-of select="$contents"/>
  </axsl:variable>
  <!--then abend if the end result has non-white-space text in it-->
  <axsl:if test="normalize-space(string($result))">
    <axsl:message terminate="yes">
      <axsl:value-of select="string($result)" disable-output-escaping="yes"/>
    </axsl:message>
  </axsl:if>
</xsl:template>

<!--process a message generated by a failed assertion-->
<xsl:template name="process-message">
  <!--express the message information-->
  <xsl:apply-templates mode="text"/>
  <!--follow it with an XPath address-->
  <axsl:text>: </axsl:text>
  <axsl:apply-templates select="." mode="schematron-get-full-path-2"/>
  <axsl:text xml:space="preserve">
</axsl:text>
</xsl:template>

</xsl:stylesheet>